#
# spec file for package python-matrix-nio
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-matrix-nio
Version:        0.23.0
Release:        1.6
Summary:        A Python Matrix client library, designed according to sans I/O principles
License:        ISC
URL:            https://github.com/poljar/matrix-nio
Source:         https://files.pythonhosted.org/packages/source/m/matrix_nio/matrix_nio-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-aiofiles >= 0.6.0
Requires:       python-aiohttp >= 3.8.6
Requires:       python-aiohttp-socks >= 0.7.0
Requires:       python-h11 >= 0.12.0
Requires:       python-h2 >= 4.0.0
Requires:       python-jsonschema >= 3.2.0
Requires:       python-pycryptodome >= 3.10.1
Requires:       python-unpaddedbase64 >= 2.1.0
Suggests:       python-atomicwrites >= 1.4.0
Suggests:       python-cachetools >= 4.2.1
Suggests:       python-dataclasses >= 0.7
Suggests:       python-peewee >= 3.14.4
Suggests:       python-python-olm >= 3.1.3
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module aiofiles >= 0.6.0}
BuildRequires:  %{python_module aiohttp >= 3.8.6}
BuildRequires:  %{python_module aiohttp-socks >= 0.7.0}
BuildRequires:  %{python_module h11 >= 0.12.0}
BuildRequires:  %{python_module h2 >= 4.0.0}
BuildRequires:  %{python_module jsonschema >= 3.2.0}
BuildRequires:  %{python_module pycryptodome >= 3.10.1}
BuildRequires:  %{python_module unpaddedbase64 >= 2.1.0}
# /SECTION
%python_subpackages

%description
A Python Matrix client library, designed according to sans I/O principles.

%prep
%autosetup -p1 -n matrix_nio-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%doc README.md
%license LICENSE.md
%{python_sitelib}/nio
%{python_sitelib}/matrix_nio-%{version}*-info

%changelog
* Mon Nov 20 2023 Matej Cepl <mcepl@cepl.eu>
- Update to 0.23.0:
  - Bug Fixes
  - Allow custom ToDeviceEvents via UnknownToDeviceEvent
  - Remove callback execution boilerplate + allow arbitrary
    callable/awaitable objects
  - Fix schemas for m.room.avatar and m.room.canonical_alias
  - Propagate asyncio.CancelledError in sync_forever
  - Features
  - Introduce the DM room account data (m.direct)
  - Miscellaneous Tasks
  - Update the nio-bot description
  - Bump aiohttp from 3.8.5 to 3.8.6
- Update to 0.22.1:
  - Fix ImportError from when e2e is not installed
- Update to 0.22.0:
  - Bug Fixes
  - Fix space handling to account for Matrix spec ambiguities.
  - Features
  - Add a simple streamed response to download to files
  - Add get space hierarchy capability
  - Support for Token-Authenticated Registration
  - Add room_type to room_create API function to allow for
    custom room types
  - Add support for m.reaction events
  - Miscellaneous Tasks
  - Add .readthedocs.yaml v2 to support ReadTheDocs migration
  - Remove future dependency
  - Fix jsonschema deprecations
  - Replace cgi.parse_header()
  - Run pre-commit autoupdate to fix deprecation
  - Introduce ruff as a pre-commit hook + run on whole codebase
  - Update pre-commit hooks
  - Replace ALL type comments with type hints
  - Add pyupgrade, async, various flake8, Perflint, and more
    ruff linting rules
- Remove upstreamed patch:
  - remove-future-requirement.patch
* Mon Sep  4 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.21.2:
  * Breaking Changes
    + [#416] Drop support for end-of-life python3.7
    + [#413] Drop usage of logbook in favor of standard library logging
  * Features
    + [#409] Support m.space.parent and m.space.child events
    + [#418] Add ability to knock on a room, and enable knocking for a room
  * Miscellaneous Tasks
    + [#401] Removing skip for passing test
    + [#406] [#407] [#414] Add content to built-with-nio
  * Bug Fixes
    + [#422] async_client.whoami will alter the state of async_client
    correctly, and accept all spec-compliant fields.
    + [#408] Properly generate code coverage
- Add patch remove-future-requirement.patch, dropping dependency on future.
* Tue Jul 18 2023 Matej Cepl <mcepl@suse.com>
- Update to 0.20.2:
  - Miscellaneous Tasks
  - Upgrade dependencies
  - Various test, formatting, type hinting fixes
  - Update GitHub Workflow Actions versions for CI
  - [#384] Add content to built-with-nio
  - Remove the usage of the imp module
  - Fix our import order
  - Fix a bunch of typos
  - Remove key re-sharing
  - Remove some unnecessary test code
  - Add poetry to the test requirements
  - Style fixes
  - Sort our imports
  - Bug Fixes
  - [#335] Default to the configured request timeout when
    syncing
  - [#354] Fix first_sync_filter parameter of
    AsyncClient.sync_forever
  - [#357] Element exports keys without required fields
  - [#396] Fix timeline->limited being required
  - Fix Python 3.11 compatibility
  - Fix import sequence errors.
  - Exclude tests/data/ from pre-commit workflow.
  - Only accept forwarded room keys from our own trusted
    devices
  - Documentation
  - Mention that room key backups are unsupported.
  - Add matrix-webhook to built-with-nio
  - Add matrix-asgi to built-with-nio
  - Features
  - Add mxc URI parameter to AsyncClient.download and deprecate
    server_name and media_id.
  - Refactor
  - Clean up and make a bunch of tests more consistent
  - Styling
  - Add config for pre-commit.
  - Fix formatting using black and isort.
  - Convert from str.format to f-strings.
  - Testing
  - Update test for AsyncClient.download.
  - Fix our async tests
* Wed Feb 16 2022 Matej Cepl <mcepl@suse.com>
- Initial packaging effort for matrix-nio 0.19.0.
